;-----------------------------------------------------------------------------
; SKIPJACK test program - part of SKIPJACK distribution
; Copyright 1998, 1999 Eric Smith
; $Id: sjtest.asm,v 1.2 1999/05/07 02:07:39 eric Exp $
;
; WARNING: This software may be subject to export controls
;
; http://www.brouhaha.com/~eric/pic/
; http://www.brouhaha.com/~eric/crypto/
;
; SKIPJACK is free software; you can redistribute it and/or modify it
; under the terms of the GNU General Public License version 2 as published by
; the Free Software Foundation.  Note that I am not granting permission to
; redistribute or modify SKIPJACK under the terms of any later version of
; the General Public License.
;
; This program is distributed in the hope that it will be useful (or at least
; amusing), but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
; Public License for more details.
;
; You should have received a copy of the GNU General Public License along with
; this program (in the file "COPYING"); if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;
; This software has been tested using the GPASM assembler:
;	http://reality.sgi.com/jamesb/gpasm/
; and the PSIM simulator:
;	http://www.brouhaha.com/~eric/pic/psim.html
;
; It may work with Microchip's MPASM assembler, but has not been tested.
;-----------------------------------------------------------------------------

	radix	dec

; This test program is only intended for use on the PSIM simulator.
#define simulator

; To get cycle counts from PSIM, uncomment the following define
;#define benchmark

;-----------------------------------------------------------------------------
; processor
;-----------------------------------------------------------------------------

	processor	16c84

rambase	equ	0x0c
rombase	equ	0x000


;-----------------------------------------------------------------------------
; register and bit definitions common to all midrange PICs
;-----------------------------------------------------------------------------

w	equ	0
f	equ	1

indf	equ	0x00
tmr0	equ	0x01
pcl	equ	0x02
status	equ	0x03
fsr	equ	0x04
porta	equ	0x05
portb	equ	0x06
pclath	equ	0x0a

optreg	equ	0x81
trisa	equ	0x85
trisb	equ	0x86

; bits in status register

irp    equ	 7
rp1    equ	 6
rp0    equ	 5
to     equ	 4
pd     equ	 3
z      equ	 2
dc     equ	 1
c      equ	 0

; bits in option register

rbpu   equ	 7
intedg equ	 6
t0cs   equ	 5
t0se   equ	 4
psa    equ	 3
ps2    equ	 2
ps1    equ	 1
ps0    equ	 0

	
;-----------------------------------------------------------------------------
; ASCII characters
;-----------------------------------------------------------------------------

cr	equ	0x0d
lf	equ	0x0a


;-----------------------------------------------------------------------------
; macros for special PSIM instructions
;-----------------------------------------------------------------------------

	ifdef simulator
output	macro			; output a character to simulator console
	data	0x00b
	endm
	endif


	ifdef simulator
	ifdef benchmark
mark	macro			; output cycle count to simulator console
	data	0x00c
	endm
	else
mark	macro
	endm
	endif
	endif

	
halt	macro
	goto	$
	endm


;-----------------------------------------------------------------------------
; RAM allocation
;-----------------------------------------------------------------------------

	cblock	rambase

	count

	tot_vec
	good_enc
	bad_enc
	good_dec
	bad_dec

	endc


;-----------------------------------------------------------------------------
; start of ROM
;-----------------------------------------------------------------------------

	org	rombase

	goto	reset
	nop
	nop
	nop
	goto	reset		; we're not using interrupts


;-----------------------------------------------------------------------------
; message table
;-----------------------------------------------------------------------------

message_page	equ	$>>8

msgtab:  addwf   PCL

banner  equ     $-(msgtab+1)
        dt      cr,lf,"SKIPJACK for PIC",cr,lf
	dt	"Copyright 1998 Eric Smith"
crlf	equ     $-(msgtab+1)
	dt	cr,lf,0
donemsg	equ     $-(msgtab+1)
	dt	"Test completed.  Total vectors: ",0
encmsg	equ     $-(msgtab+1)
	dt	"Encryptions ",0
decmsg	equ     $-(msgtab+1)
	dt	"Decryptions ",0
pcntmsg	equ     $-(msgtab+1)
	dt	"passed: ",0
fcntmsg	equ     $-(msgtab+1)
	dt	", failed: ",0
passmsg	equ     $-(msgtab+1)
	dt	"  pass",0
failmsg	equ     $-(msgtab+1)
	dt	"  FAIL!!!  Should be: ",0
keymsg	equ     $-(msgtab+1)
        dt      "Key:         ",0
plaintextmsg	equ     $-(msgtab+1)
        dt      "Plaintext:   ", 0
ciphertextmsg	equ     $-(msgtab+1)
	dt	"Ciphertext:  ", 0

        if      (msgtab>>8)!=($>>8)
        error   "messages must reside within a single page"
        endif


;-----------------------------------------------------------------------------
; utility functions
;-----------------------------------------------------------------------------

print_key:
	movlw	keymsg
	call	msgout
	movlw	key
	movwf	fsr
	movlw	keylen
	movwf	count
	goto	outhexram


print_plaintext:
	movlw	plaintextmsg
	goto	print_text

print_ciphertext:
	movlw	ciphertextmsg
print_text:
	call	msgout
print_block:
	movlw	text
	movwf	fsr
	movlw	blocklen
	movwf	count
	goto	outhexram


outhexram:
	movf	indf,w
	call	outhb
	incf	fsr
	decfsz	count
	goto	outhr1
	return
outhr1:	movlw	'.'
	call	xmit
	goto	outhexram


;-----------------------------------------------------------------------------
; output a byte in hexadecimal
; uses temp
;-----------------------------------------------------------------------------

outhb:  movwf   temp
outhb1: swapf   temp,w
        call    outhd
        movf    temp,w

; fall into outhd

;-----------------------------------------------------------------------------
; output a hex digit
;-----------------------------------------------------------------------------

outhd:  andlw   0x0f
        addlw   0xf6
        btfsc   status,c
        addlw   0x07
        addlw   0x3a

; fall into xmit

;-----------------------------------------------------------------------------
; serial transmit character
;-----------------------------------------------------------------------------

xmit:	output			; works for simulator only
	return


;-----------------------------------------------------------------------------
; message output subroutine
;-----------------------------------------------------------------------------

msgout: movwf   temp
        movlw   message_page
        movwf   pclath
msglp:  movf    temp,W
        call    msgtab
        xorlw   0
        btfsc   status,z
        return
        call    xmit
        incf    temp
        goto    msglp


;-----------------------------------------------------------------------------
; initialization code
;-----------------------------------------------------------------------------

reset:
        movlw   0xff            ; all port pins are inputs (or inactive
        tris    porta           ; open-drain outputs)
        tris    portb
        clrf    porta
        clrf    portb

	clrf	tot_vec
	clrf	good_enc
	clrf	bad_enc
	clrf	good_dec
	clrf	bad_dec
	
	movlw	banner
	call	msgout


;-----------------------------------------------------------------------------
; main loop
;-----------------------------------------------------------------------------

main:	call	init_test_vec

loop:	incf	tot_vec

	movlw	key
	movwf	fsr

	call	get_test_vec_key
	call	print_key
	movlw	crlf
	call	msgout

	movlw	text
	movwf	fsr

	call	get_test_vec_block
	call	print_plaintext
	movlw	crlf
	call	msgout

	mark
	call	encrypt
	mark
	
	call	print_ciphertext

	movlw	text
	movwf	fsr

	call	compare_test_vec_block
	btfss	status,z
	goto	enc_fail

	incf	good_enc
	movlw	passmsg
	call	msgout
	movlw	crlf
	call	msgout
	goto	do_dec

enc_fail:
	incf	bad_enc
	movlw	failmsg
	call	msgout

	call	backup_test_vec_block
	call	get_test_vec_block
	call	print_block
	movlw	crlf
	call	msgout

do_dec:
	mark
	call	decrypt
	mark

	call	print_plaintext

	movlw	text
	movwf	fsr

	call	backup_test_vec_block
	call	backup_test_vec_block
	call    compare_test_vec_block
	btfss	status,z
	goto	dec_fail

	incf	good_dec
	movlw	passmsg
	call	msgout
	movlw	crlf
	call	msgout
	goto	do_next

dec_fail:
	incf	bad_dec
	movlw	failmsg
	call	msgout

	call	backup_test_vec_block
	call	get_test_vec_block
	call	print_block
	movlw	crlf
	call	msgout
	
do_next:
	call	skip_test_vec_block
	movlw	crlf
	call	msgout
	
	movlw	crlf
	call	msgout

	call	end_of_test_vec
	btfss   status,z
	goto    loop
	
	movlw	donemsg
	call	msgout
	movf	tot_vec,w
	call	outhb
	movlw	crlf
	call	msgout

	movlw	encmsg
	call	msgout
	movlw	pcntmsg
	call	msgout
	movf	good_enc,w
	call	outhb
	movlw	fcntmsg
	call	msgout
	movf	bad_enc,w
	call	outhb
	movlw	crlf
	call	msgout
	
	movlw	decmsg
	call	msgout
	movlw	pcntmsg
	call	msgout
	movf	good_dec,w
	call	outhb
	movlw	fcntmsg
	call	msgout
	movf	bad_dec,w
	call	outhb
	movlw	crlf
	call	msgout
	
	halt


;-----------------------------------------------------------------------------
; don't forget to include the actual SKIPJACK code and F-table
;-----------------------------------------------------------------------------

        include "skipjack.inc"

;-----------------------------------------------------------------------------
; test vectors
;-----------------------------------------------------------------------------

	include	"testvec.inc"


	end
