;-----------------------------------------------------------------------------
; SKIP test vectors - part of SKIPJACK distribution
; Copyright 1998, 1999 Eric L. Smith
; $Id: testvec.inc,v 1.3 1999/05/07 02:07:39 eric Exp $
;
; WARNING: This software may be subject to export controls
;
; http://www.brouhaha.com/~eric/pic/
; http://www.brouhaha.com/~eric/crypto/
;
; SKIPJACK is free software; you can redistribute it and/or modify it
; under the terms of the GNU General Public License version 2 as published by
; the Free Software Foundation.  Note that I am not granting permission to
; redistribute or modify SKIPJACK under the terms of any later version of
; the General Public License.
;
; This program is distributed in the hope that it will be useful (or at least
; amusing), but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
; Public License for more details.
;
; You should have received a copy of the GNU General Public License along with
; this program (in the file "COPYING"); if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;
; This software has been tested using the GPASM assembler:
;	http://reality.sgi.com/jamesb/gpasm/
; and the PSIM simulator:
;	http://www.brouhaha.com/~eric/pic/psim.html
;
; It may work with Microchip's MPASM assembler, but has not been tested.
;-----------------------------------------------------------------------------


;-----------------------------------------------------------------------------
; RAM definitions
;-----------------------------------------------------------------------------

	cblock
	vec_ptr: 2
	endc


;-----------------------------------------------------------------------------
; init_test_vec
;-----------------------------------------------------------------------------

init_test_vec:
	movlw	test_vec_tab&0xff
	movwf	vec_ptr
	movlw	test_vec_tab>>8
	movwf	vec_ptr+1
	return


;-----------------------------------------------------------------------------
; backup_test_vec_block
;-----------------------------------------------------------------------------

backup_test_vec_block:
	movlw	-blocklen
	addwf	vec_ptr
	btfss	status,c
	decf	vec_ptr+1
	return


;-----------------------------------------------------------------------------
; skip_test_vec_block
;-----------------------------------------------------------------------------

skip_test_vec_block:
	movlw	blocklen
	addwf	vec_ptr
	btfsc	status,c
	incf	vec_ptr+1
	return


;-----------------------------------------------------------------------------
; end_of_test_vec
;-----------------------------------------------------------------------------

end_of_test_vec:
	movf	vec_ptr,w
	xorlw	test_vec_tab_end&0xff
	btfss	status,z
	return
	movf	vec_ptr+1,w
	xorlw	test_vec_tab_end>>8
	return


;-----------------------------------------------------------------------------
; get one byte from test vector array, and advance pointer
;-----------------------------------------------------------------------------

get_test_vec_byte:

	movf	vec_ptr+1,w
	movwf	pclath
	movf	vec_ptr,w

	incf	vec_ptr
	btfsc	status,z
	incf	vec_ptr+1

        movwf   pcl


;-----------------------------------------------------------------------------
; copies keylen bytes of data from the test vector array into the RAM
; pointed to by FSR.
;
; on exit, the test vector pointer is increased by keylen, but FSR is
; unchanged
;
; uses count
;-----------------------------------------------------------------------------

get_test_vec_key:
        movlw   keylen
        movwf   count
gtvk0:	call    get_test_vec_byte
	clrf	pclath
        movwf   indf
        incf    fsr
        decfsz  count
        goto    gtvk0
        movlw   -keylen
        addwf   fsr
        return


;-----------------------------------------------------------------------------
; copies blocklen bytes of data from the test vector array into the RAM
; pointed to by FSR.
;
; on exit, the test vector pointer is increased by blocklen, but FSR is
; unchanged
;
; uses count
;-----------------------------------------------------------------------------

get_test_vec_block:
        movlw   blocklen
        movwf   count
gtvb0:	call    get_test_vec_byte
	clrf	pclath
        movwf   indf
        incf    fsr
        decfsz  count
        goto    gtvb0
        movlw   -blocklen
        addwf   fsr
        return


;-----------------------------------------------------------------------------
; compares blocklen bytes of data from the test vector array to the RAM
; pointed to by FSR.
;
; on exit, the test vector pointer is increased by blocklen, but FSR is
; unchanged.  The zero flag will be set if the test vector is equal to the
; RAM value.
;
; uses count, temp
;-----------------------------------------------------------------------------

compare_test_vec_block:
        movlw   blocklen
        movwf   count
	clrf	temp
ctvb0:	call    get_test_vec_byte
	clrf	pclath
        xorwf   indf,w
	iorwf	temp
        incf    fsr
        decfsz  count
        goto    ctvb0
        movlw   -blocklen
        addwf   fsr
	movf	temp		; set Z flag appropriately
        return


;-----------------------------------------------------------------------------
; and finally, the actual test vectors
;-----------------------------------------------------------------------------

test_vec_tab:

; This vector is from the SKIPJACK protocol specification:

	dt	0x00,0x99,0x88,0x77,0x66,0x55,0x44,0x33,0x22,0x11	; key
	dt	0x33,0x22,0x11,0x00,0xdd,0xcc,0xbb,0xaa ; plaintext 
	dt	0x25,0x87,0xca,0xe2,0x7a,0x12,0xd3,0x00 ; ciphertext

; Unfortunately that's the only "official" vector we have.  It really
; sucks that the specification doesn't contain more vectors, as this one
; only covers 104 of the 256 entries of the F table.

; Here are some more that were posted to the Usenet newsgroup sci.crypt by
; Jason Stratos Papadopoulos <jasonp@glue.umd.edu> on 27-Jun-1998
;	http://www.dejanews.com/getdoc.xp?AN=366465228

        dt      0xf8,0xda,0x02,0x64,0x77,0x22,0xf7,0x10,0x3a,0xdf       ; key
        dt      0x1d,0xdf,0x39,0xab,0xf5,0xcd,0x71,0x1e ; plaintext 
        dt      0xc9,0x2d,0x22,0x32,0x4c,0x6b,0x31,0xae ; ciphertext

        dt      0x82,0x76,0x0a,0xc1,0x37,0x94,0x88,0x21,0xee,0xe4       ; key
        dt      0xdd,0x6c,0x6c,0xce,0x8f,0x83,0xe6,0x9e ; plaintext 
        dt      0xe3,0x28,0x77,0xc1,0xd9,0x52,0x7f,0xff ; ciphertext
		                 	                       	             
        dt      0x84,0x3c,0x16,0x87,0xd3,0xcd,0xca,0x5f,0xc5,0xc3       ; key
        dt      0xbe,0xaa,0xcf,0x17,0x7f,0xa4,0x1a,0x11 ; plaintext 
        dt      0x47,0x45,0x78,0x3f,0x75,0xb8,0x86,0x1a ; ciphertext
		                 	                       	             
        dt      0xae,0x87,0x0c,0xd7,0xff,0x33,0xa9,0x95,0xf7,0xe5       ; key
        dt      0xc4,0xc0,0x9f,0x21,0x6c,0x1b,0xc6,0x0a ; plaintext 
        dt      0x5c,0x10,0x16,0x36,0xb8,0xa5,0x7a,0x72 ; ciphertext
		                 	                       	             
        dt      0x5c,0xcb,0xd9,0x13,0xea,0x8b,0x73,0xbd,0x63,0x91       ; key
        dt      0xd3,0xf8,0x14,0xb0,0x00,0x24,0x58,0x56 ; plaintext 
        dt      0xb4,0xfc,0x0f,0x8e,0x54,0x72,0x8f,0x91 ; ciphertext
		                 	                       
        dt      0xf6,0x5e,0x74,0xcd,0x59,0x9c,0x68,0xa4,0x0c,0xc7       ; key
        dt      0x35,0x6e,0xc7,0xd9,0x38,0x32,0x32,0x9c ; plaintext 
        dt      0x93,0xb7,0x50,0x60,0x8f,0x57,0x01,0xf8 ; ciphertext
		                 	                       	               
        dt      0xaa,0x10,0x6e,0x46,0xd7,0x08,0x7c,0x4e,0x93,0xdc       ; key
        dt      0x20,0x9e,0xcf,0x1c,0x53,0x7a,0xd5,0x6c ; plaintext 
        dt      0xd8,0x23,0xd4,0x55,0x10,0x09,0x9e,0x61 ; ciphertext
		                 	                       	               
        dt      0xa9,0x3f,0x97,0x89,0xa2,0x0c,0x3c,0xc3,0x4f,0xea       ; key
        dt      0x89,0x2e,0xea,0x9d,0x64,0xe1,0x7d,0x66 ; plaintext 
        dt      0x09,0x59,0xe2,0x31,0xb2,0x75,0xd9,0x5f ; ciphertext
		                 	                       	               
        dt      0x88,0xb1,0x63,0xcb,0xd6,0x16,0x16,0x88,0x88,0x99       ; key
        dt      0x99,0x13,0x90,0xfd,0x76,0x0f,0xc9,0x1b ; plaintext 
        dt      0xe7,0x70,0x02,0x09,0x88,0x67,0x67,0xae ; ciphertext
		                 	                       	               
        dt      0xfb,0x6c,0xd1,0xff,0x70,0x48,0x75,0x61,0xdf,0x10       ; key
        dt      0xda,0xeb,0xc9,0x47,0xdd,0xca,0x9c,0x9e ; plaintext 
        dt      0xe7,0xcc,0x49,0xa5,0x6b,0xd6,0xa3,0x22 ; ciphertext
		                 	                       
        dt      0x5e,0xdc,0x1a,0xc0,0xc4,0xe7,0xef,0x5f,0x00,0x2c       ; key
        dt      0x64,0x19,0xdd,0xef,0xe2,0xcd,0x8f,0x2e ; plaintext 
        dt      0xe4,0x8a,0x05,0xcf,0x26,0xe2,0x42,0xfd ; ciphertext
		                 	                       	               
        dt      0x8e,0x30,0x90,0xc1,0x9a,0xa3,0x2f,0x94,0x49,0x6a       ; key
        dt      0x32,0x29,0x98,0xec,0xbd,0x06,0x81,0x12 ; plaintext 
        dt      0x62,0xc0,0xe5,0x37,0xb1,0x4d,0xf2,0xc1 ; ciphertext
		                 	                       	               
        dt      0xb9,0x6e,0x3f,0xd4,0x6f,0xa4,0x26,0x3f,0x90,0x92       ; key
        dt      0x3a,0xae,0x2a,0xee,0x20,0xda,0x93,0xcc ; plaintext 
        dt      0x54,0xd1,0xe5,0x8a,0x6b,0x62,0x4d,0x71 ; ciphertext
		                 	                       	               
        dt      0x9e,0x66,0x35,0xba,0xee,0x28,0xc5,0xbc,0xe2,0xbc       ; key
        dt      0x14,0x31,0x11,0x12,0xca,0x11,0xf7,0x27 ; plaintext 
        dt      0x5d,0x0f,0x23,0x5a,0x9d,0x22,0x1c,0xe0 ; ciphertext
		                 	                       	               
        dt      0x04,0x12,0x7c,0xe1,0x6d,0xc1,0xb1,0x72,0x6a,0x66       ; key
        dt      0x30,0x0e,0x43,0x13,0xe7,0xad,0x67,0x96 ; plaintext 
        dt      0x8e,0x5b,0x03,0x52,0x2e,0x68,0xcb,0xeb ; ciphertext
		                 	                       	   
        dt      0xf0,0xb8,0x9d,0x75,0xe9,0x79,0xcc,0xc9,0xb1,0x72       ; key
        dt      0x09,0xcd,0x1c,0x1a,0xcc,0xbe,0x77,0x97 ; plaintext 
        dt      0x57,0x2c,0x9b,0x40,0x25,0xa9,0x13,0x4b ; ciphertext
		                 	                       	               
        dt      0xf9,0xbf,0xc7,0x87,0x98,0xcb,0xf1,0xbc,0xd4,0xb5       ; key
        dt      0x31,0xb3,0x0c,0xa3,0x54,0xaf,0x3c,0xd8 ; plaintext 
        dt      0x8c,0x95,0x9c,0x90,0x47,0x89,0xfb,0xda ; ciphertext
		                 	                       	               
        dt      0xf4,0x3a,0x51,0xb4,0x27,0x3b,0xde,0x27,0xd2,0xb0       ; key
        dt      0x08,0xc5,0x9b,0x0d,0xb9,0x9e,0xc2,0x67 ; plaintext 
        dt      0xb7,0xd7,0xf5,0xfa,0x34,0x29,0x88,0xfb ; ciphertext
		                 	                       	               
        dt      0xcd,0x51,0xf0,0xa7,0x5a,0xa7,0x3c,0x48,0xed,0xd2       ; key
        dt      0x97,0x84,0xb1,0xe3,0xe7,0xe6,0x0e,0x60 ; plaintext 
        dt      0x76,0x3a,0xa8,0xee,0x10,0x93,0x97,0xb3 ; ciphertext
		                 	                       	               
        dt      0xb3,0x31,0x9a,0x3f,0x66,0x22,0xaa,0x72,0x6b,0xb3       ; key
        dt      0xf6,0x52,0x16,0x37,0x3d,0x4b,0x43,0xc7 ; plaintext 
        dt      0x03,0x25,0x60,0x03,0x37,0xb8,0xad,0x3c ; ciphertext
		                 	                       
        dt      0x49,0x32,0x54,0xc9,0x59,0x6e,0x99,0x3f,0x5f,0x9c       ; key
        dt      0xcb,0xa4,0xc1,0x21,0x5d,0x5d,0x36,0xce ; plaintext 
        dt      0x68,0xe1,0xc5,0x51,0xc5,0x91,0x08,0xc0 ; ciphertext
		                 	                       	               
        dt      0x76,0x15,0x0c,0x2c,0x3c,0xed,0x1c,0x7c,0xa0,0x21       ; key
        dt      0x82,0x29,0x48,0x51,0x28,0x8e,0x75,0xcb ; plaintext 
        dt      0x7e,0xb6,0x32,0x5d,0x82,0xa2,0x09,0x6c ; ciphertext
		                 	                       	               
        dt      0x71,0x40,0xd6,0xc5,0x48,0x63,0x05,0x87,0x2d,0xf6       ; key
        dt      0xc3,0xa7,0xb7,0xe4,0xa5,0x2e,0x40,0x7b ; plaintext 
        dt      0x24,0x83,0xf3,0x85,0xa4,0x2e,0xe3,0xc6 ; ciphertext
		                 	                       	               
        dt      0x3c,0x2c,0x39,0x01,0xf0,0xee,0x9a,0x3b,0x2b,0x0e       ; key
        dt      0x1b,0xfd,0xe3,0x2a,0xb5,0x59,0xe1,0x3a ; plaintext 
        dt      0xd6,0xfa,0x9d,0xb8,0x68,0x5f,0xd8,0x8a ; ciphertext
		                 	                       	               
        dt      0x60,0x6a,0x8b,0x4b,0xdf,0xaa,0xe8,0xa0,0xba,0x51       ; key
        dt      0xd2,0x05,0xf7,0x48,0x6c,0x78,0x28,0x38 ; plaintext 
        dt      0x03,0x30,0x48,0x91,0x70,0xb8,0x52,0x93 ; ciphertext
		                 	                       	   
        dt      0x78,0x47,0xa4,0x7a,0x0f,0xe7,0x9a,0xb7,0x70,0xce       ; key
        dt      0xd9,0x6f,0xf1,0xf7,0xc7,0xfc,0x60,0xe0 ; plaintext 
        dt      0x1f,0x9b,0x33,0x01,0xc9,0xb2,0x70,0x8c ; ciphertext
		                 	                       	               
        dt      0x73,0xb9,0xab,0x0c,0x36,0xc9,0x9e,0x91,0xa8,0x91       ; key
        dt      0x24,0x1d,0x4b,0xde,0x19,0xa7,0x5f,0x8f ; plaintext 
        dt      0x2b,0x86,0xc5,0x7f,0xfe,0x16,0x88,0x95 ; ciphertext
		                 	                       	               
        dt      0xa3,0x7f,0x2a,0xd5,0xa8,0x5e,0x17,0x07,0x41,0xf5       ; key
        dt      0x7b,0xe1,0xb8,0xd5,0x83,0x21,0xc6,0x19 ; plaintext 
        dt      0x5a,0xf7,0xce,0xb3,0xee,0xd9,0xdc,0xa1 ; ciphertext
		                 	                       	               
        dt      0xf7,0xb0,0xc2,0xa8,0x17,0x0e,0x3c,0x4e,0x48,0xb3       ; key
        dt      0xc9,0x21,0x4e,0xa0,0x1e,0xc1,0x49,0x48 ; plaintext 
        dt      0x1b,0x58,0x77,0x36,0xe1,0x16,0xc0,0x4b ; ciphertext
		                 	                       	               
        dt      0xa1,0xfc,0x67,0xe4,0x4e,0xac,0xac,0xf4,0xa9,0x02       ; key
        dt      0xe2,0xa3,0x09,0x1f,0xeb,0x58,0x15,0x88 ; plaintext 
        dt      0xf3,0xec,0xf0,0xf1,0x78,0x9a,0x39,0x23 ; ciphertext
		                 	                       
        dt      0xf1,0x44,0x30,0xaf,0xfc,0x5f,0xe8,0x2a,0x9a,0xe9       ; key
        dt      0x3c,0xb4,0x66,0xd3,0x01,0xb6,0x08,0x54 ; plaintext 
        dt      0xe8,0xd1,0x14,0xc2,0x0f,0xfa,0x1c,0x79 ; ciphertext
		                 	                       	               
        dt      0xfd,0x26,0xdf,0x50,0x48,0x6a,0x4c,0xd9,0x6d,0x9b       ; key
        dt      0xb0,0x68,0x4f,0x8a,0x5e,0x63,0xd9,0x35 ; plaintext 
        dt      0x22,0x29,0x03,0x99,0x4d,0x64,0xfe,0x3a ; ciphertext
		                 	                       	               
        dt      0xa6,0xd4,0x6d,0x46,0xca,0x28,0x7e,0x1a,0x33,0x2a       ; key
        dt      0xba,0x1f,0x37,0xe8,0x8e,0xde,0xc5,0x5f ; plaintext 
        dt      0x91,0xf2,0xba,0xad,0x6f,0xa0,0xde,0x55 ; ciphertext
		                 	                       	               
        dt      0x83,0xc3,0xf1,0xcb,0x8d,0x06,0xef,0xc6,0x19,0x6b       ; key
        dt      0xe9,0xfe,0xd8,0x50,0x1b,0x7a,0x65,0x79 ; plaintext 
        dt      0x83,0xf9,0xf0,0x8f,0x89,0xa8,0x54,0xee ; ciphertext
		                 	                       	               
        dt      0x0e,0xdf,0xa4,0x4c,0x7d,0x4a,0x4e,0xf0,0x72,0x5e       ; key
        dt      0xeb,0x5c,0xa8,0xb3,0xfa,0x1f,0xcd,0xbb ; plaintext 
        dt      0x2b,0x1b,0x66,0x70,0xa6,0xbe,0x03,0x24 ; ciphertext
		                 	                       	   
        dt      0xb8,0xed,0xcf,0x16,0x7d,0x99,0xa7,0x11,0xcc,0xee       ; key
        dt      0xb8,0xb5,0x25,0xc6,0x38,0x2a,0xf2,0x77 ; plaintext 
        dt      0x21,0x1a,0x69,0x5d,0xa4,0x73,0x76,0x6f ; ciphertext
		                 	                       	               
        dt      0x4f,0x63,0x9e,0x0d,0x5a,0x5d,0x2a,0xd7,0xe9,0xa4       ; key
        dt      0x91,0x62,0xe7,0x81,0xff,0x68,0x38,0x53 ; plaintext 
        dt      0xeb,0x29,0x76,0x37,0x0d,0x22,0xef,0x22 ; ciphertext
		                 	                       	               
        dt      0x37,0xe0,0x06,0x25,0x6a,0x4a,0xe6,0xd3,0x20,0xc4       ; key
        dt      0xc9,0xf2,0x3a,0x20,0xa3,0x9d,0xed,0x11 ; plaintext 
        dt      0xdb,0xa4,0xc0,0xef,0x0e,0xa0,0x98,0xc0 ; ciphertext
		                 	                       	               
        dt      0xe4,0x1d,0x0b,0xd2,0x5f,0x93,0x1b,0xa1,0xd8,0x5c       ; key
        dt      0x5a,0x6f,0x12,0xf3,0x2f,0x7e,0xef,0xdf ; plaintext 
        dt      0x92,0x3d,0xae,0xe8,0x00,0x07,0x09,0xf9 ; ciphertext
		                 	                       	               
        dt      0xfd,0xf6,0x5b,0xbc,0x5f,0xe6,0x00,0xf3,0xcd,0x68       ; key
        dt      0xca,0xd5,0x41,0x4c,0x1c,0x64,0xf1,0x94 ; plaintext 
        dt      0xd5,0x77,0x1e,0x78,0xb6,0xf1,0xfe,0x1e ; ciphertext
		                 	                       
        dt      0x1c,0x26,0x9a,0xf2,0xff,0x16,0x6a,0xcb,0x27,0xef       ; key
        dt      0x06,0x3a,0x58,0xa2,0x0b,0x45,0x37,0x8f ; plaintext 
        dt      0x63,0x4f,0x7a,0x38,0x61,0xaf,0x97,0xa1 ; ciphertext
		                 	                       	               
        dt      0x11,0x79,0xf6,0x4a,0xcb,0x61,0x22,0xcc,0xf6,0x49       ; key
        dt      0x08,0xfb,0xf4,0x2b,0x43,0x13,0x34,0x7b ; plaintext 
        dt      0x3a,0x80,0x3a,0x4b,0xd0,0xe8,0xc3,0xe6 ; ciphertext
		                 	                       	               
        dt      0x07,0x8c,0x87,0x26,0x5e,0xb8,0xda,0x32,0x3e,0x90       ; key
        dt      0x6d,0x4e,0xd0,0xe9,0x93,0x05,0x32,0xd1 ; plaintext 
        dt      0xf4,0xfa,0x37,0x2e,0x7e,0x14,0x41,0xa1 ; ciphertext
		                 	                       	               
        dt      0x2f,0xff,0x35,0xf8,0xeb,0x77,0x4c,0x84,0x3b,0xb0       ; key
        dt      0x40,0xb6,0x99,0x81,0x23,0x45,0x66,0x1d ; plaintext 
        dt      0x63,0xa9,0x19,0x7f,0x7b,0x75,0xf5,0x3f ; ciphertext
		                 	                       	               
        dt      0x09,0xf7,0x73,0x46,0xa4,0x39,0x3c,0xe9,0x98,0x56       ; key
        dt      0x22,0xed,0x54,0x62,0x6a,0x51,0xe5,0x05 ; plaintext 
        dt      0xe9,0x1a,0x05,0x0a,0x74,0x81,0xb3,0xdd ; ciphertext
		                 	                       	   
        dt      0x5b,0x87,0x8e,0x0b,0x22,0xa7,0x05,0xac,0xf8,0xfb       ; key
        dt      0x0c,0x48,0x9b,0x66,0xe2,0xda,0x53,0x1b ; plaintext 
        dt      0x6e,0x93,0x70,0xa9,0x1b,0x99,0x48,0x78 ; ciphertext
		                 	                       	               
        dt      0x9d,0x72,0xc1,0xab,0x20,0x92,0xc1,0xb1,0x08,0x77       ; key
        dt      0xc6,0x4b,0x10,0xf8,0xb1,0x91,0xbc,0x2c ; plaintext 
        dt      0x5b,0xde,0xcd,0xed,0x96,0xd6,0x56,0xc9 ; ciphertext
		                 	                       	               
        dt      0x72,0x86,0x5f,0x28,0x97,0x25,0xe1,0xb5,0x55,0x02       ; key
        dt      0x91,0xfd,0xf7,0x23,0x6f,0x85,0xbd,0xd6 ; plaintext 
        dt      0x1a,0x56,0x80,0xe5,0x17,0x36,0x02,0x6f ; ciphertext
		                 	                       	               
        dt      0x06,0xe3,0xc0,0xe5,0x41,0xf4,0xaa,0xe6,0xfe,0x93       ; key
        dt      0x40,0x00,0x9f,0x8a,0x46,0x5a,0x9f,0xeb ; plaintext 
        dt      0x0e,0x7a,0xac,0xe4,0x21,0xbc,0x79,0xd8 ; ciphertext
		                 	                       	               
        dt      0x2e,0xa0,0x9f,0x1c,0xc8,0x9e,0x06,0x4f,0x09,0xbc       ; key
        dt      0x54,0x32,0x08,0xb0,0x5b,0xfa,0x38,0x58 ; plaintext 
        dt      0xa9,0x5d,0x87,0xfa,0xd1,0x2c,0x35,0x93 ; ciphertext

test_vec_tab_end:



